@@ -27,6 +27,8 @@
 #include "ptyxis-application.h"
 #include "ptyxis-util.h"
 
+static gint64 default_rlimit_nofile;
+
 static void
 check_early_opts (int        *argc,
                   char     ***argv,
@@ -50,13 +52,17 @@ check_early_opts (int        *argc,
    */
   for (int i = 0; i < *argc; i++)
     {
-      const char *arg = (*argv)[i];
+      char *arg = (*argv)[i];
 
       if (g_str_equal (arg, "--tab") ||
           g_str_equal (arg , "--new-window") ||
           (g_str_equal (arg, "--tab-with-profile") || g_str_has_prefix (arg, "--tab-with-profile=")))
         ignore_standalone = TRUE;
 
+      /* Convert -e to -- for x-terminal-emulator */
+      if (strcmp (arg, "-e") == 0)
+        arg[1] = '-';
+
       if (g_str_equal ((*argv)[i], "--") && (*argv)[i+1] != NULL)
         {
           GString *str = g_string_new (NULL);
@@ -108,6 +114,17 @@ warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n\
     }
 }
 
+static gint64
+get_current_fd_limit (void)
+{
+  struct rlimit limit;
+
+  if (getrlimit (RLIMIT_NOFILE, &limit) == 0)
+    return limit.rlim_cur;
+
+  return 0;
+}
+
 static void
 bump_to_max_fd_limit (void)
 {
@@ -126,6 +143,12 @@ bump_to_max_fd_limit (void)
     }
 }
 
+gint64
+ptyxis_application_get_default_rlimit_nofile (void)
+{
+  return default_rlimit_nofile;
+}
+
 int
 main (int   argc,
       char *argv[])
@@ -147,6 +170,7 @@ main (int   argc,
   if (standalone)
     flags |= G_APPLICATION_NON_UNIQUE;
 
+  default_rlimit_nofile = get_current_fd_limit ();
   bump_to_max_fd_limit ();
 
   gtk_init ();
