@@ -53,6 +53,7 @@ struct _PtyxisPreferencesWindow
   AdwSwitchRow         *audible_bell;
   AdwComboRow          *backspace_binding;
   AdwSwitchRow         *bold_is_bright;
+  AdwSpinRow           *cell_height_scale;
   AdwComboRow          *cjk_ambiguous_width;
   GListModel           *cjk_ambiguous_widths;
   AdwComboRow          *cursor_blink_mode;
@@ -86,6 +87,7 @@ struct _PtyxisPreferencesWindow
   GListModel           *scrollbar_policies;
   PtyxisShortcutRow    *shortcut_close_other_tabs;
   PtyxisShortcutRow    *shortcut_close_tab;
+  PtyxisShortcutRow    *shortcut_close_window;
   PtyxisShortcutRow    *shortcut_copy_clipboard;
   PtyxisShortcutRow    *shortcut_detach_tab;
   PtyxisShortcutRow    *shortcut_focus_tab_10;
@@ -106,8 +108,10 @@ struct _PtyxisPreferencesWindow
   PtyxisShortcutRow    *shortcut_new_window;
   PtyxisShortcutRow    *shortcut_paste_clipboard;
   PtyxisShortcutRow    *shortcut_popup_menu;
+  PtyxisShortcutRow    *shortcut_set_title;
   PtyxisShortcutRow    *shortcut_preferences;
   PtyxisShortcutRow    *shortcut_primary_menu;
+  PtyxisShortcutRow    *shortcut_tab_menu;
   PtyxisShortcutRow    *shortcut_reset;
   PtyxisShortcutRow    *shortcut_reset_and_clear;
   PtyxisShortcutRow    *shortcut_search;
@@ -138,6 +142,23 @@ enum {
 
 static GParamSpec *properties[N_PROPS];
 
+static gboolean
+ptyxis_preferences_window_spin_row_show_decimal_cb (PtyxisPreferencesWindow *self,
+                                                    AdwSpinRow              *spin)
+{
+  g_autofree char *text = NULL;
+  double value;
+
+  g_assert (PTYXIS_IS_PREFERENCES_WINDOW (self));
+  g_assert (ADW_IS_SPIN_ROW (spin));
+
+  value = adw_spin_row_get_value (spin);
+  text = g_strdup_printf ("%.1f", value);
+  gtk_editable_set_text (GTK_EDITABLE (spin), text);
+
+  return TRUE;
+}
+
 static void
 invalidate_filter (PtyxisPreferencesWindow *self)
 {
@@ -492,6 +513,9 @@ ptyxis_preferences_window_notify_default_profile_cb (PtyxisPreferencesWindow *se
   g_object_bind_property (profile, "bold-is-bright",
                           self->bold_is_bright, "active",
                           G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL);
+  g_object_bind_property (profile, "cell-height-scale",
+                          self->cell_height_scale, "value",
+                          G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL);
   g_object_bind_property (profile, "login-shell",
                           self->login_shell, "active",
                           G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL);
@@ -586,20 +610,6 @@ ptyxis_preferences_window_drop_palette_cb (PtyxisPreferencesWindow *self,
   return FALSE;
 }
 
-static void
-ptyxis_preferences_window_activate_palette_cb (GtkFlowBoxChild *child,
-                                               PtyxisPalette   *palette)
-{
-  g_autoptr(GVariant) param = NULL;
-
-  g_assert (GTK_IS_FLOW_BOX_CHILD (child));
-  g_assert (PTYXIS_IS_PALETTE (palette));
-
-  param = g_variant_take_ref (g_variant_new_string (ptyxis_palette_get_id (palette)));
-
-  gtk_widget_activate_action_variant (GTK_WIDGET (child), "default-profile.palette", param);
-}
-
 static GtkWidget *
 create_palette_preview (gpointer item,
                         gpointer user_data)
@@ -633,11 +643,6 @@ create_palette_preview (gpointer item,
   child = g_object_new (GTK_TYPE_FLOW_BOX_CHILD,
                         "child", button,
                         NULL);
-  g_signal_connect_object (child,
-                           "activate",
-                           G_CALLBACK (ptyxis_preferences_window_activate_palette_cb),
-                           palette,
-                           0);
 
   /* This is probably pretty slow and terrible to do here, but we need another
    * way to track default-palette of default-profile, both of which could change.
@@ -829,6 +834,9 @@ ptyxis_preferences_window_constructed (GObject *object)
   g_object_bind_property (shortcuts, "primary-menu",
                           self->shortcut_primary_menu, "accelerator",
                           G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL);
+  g_object_bind_property (shortcuts, "tab-menu",
+                          self->shortcut_tab_menu, "accelerator",
+                          G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL);
 
   g_object_bind_property (shortcuts, "copy-clipboard",
                           self->shortcut_copy_clipboard, "accelerator",
@@ -859,6 +867,10 @@ ptyxis_preferences_window_constructed (GObject *object)
                           self->shortcut_popup_menu, "accelerator",
                           G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL);
 
+  g_object_bind_property (shortcuts, "set-title",
+                          self->shortcut_set_title, "accelerator",
+                          G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL);
+
   g_object_bind_property (shortcuts, "zoom-in",
                           self->shortcut_zoom_in, "accelerator",
                           G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL);
@@ -878,6 +890,9 @@ ptyxis_preferences_window_constructed (GObject *object)
   g_object_bind_property (shortcuts, "undo-close-tab",
                           self->shortcut_undo_close_tab, "accelerator",
                           G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL);
+  g_object_bind_property (shortcuts, "close-window",
+                          self->shortcut_close_window, "accelerator",
+                          G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL);
 
   g_object_bind_property (shortcuts, "move-next-tab",
                           self->shortcut_move_next_tab, "accelerator",
@@ -979,6 +994,7 @@ ptyxis_preferences_window_class_init (PtyxisPreferencesWindowClass *klass)
   gtk_widget_class_bind_template_child (widget_class, PtyxisPreferencesWindow, audible_bell);
   gtk_widget_class_bind_template_child (widget_class, PtyxisPreferencesWindow, backspace_binding);
   gtk_widget_class_bind_template_child (widget_class, PtyxisPreferencesWindow, bold_is_bright);
+  gtk_widget_class_bind_template_child (widget_class, PtyxisPreferencesWindow, cell_height_scale);
   gtk_widget_class_bind_template_child (widget_class, PtyxisPreferencesWindow, cjk_ambiguous_width);
   gtk_widget_class_bind_template_child (widget_class, PtyxisPreferencesWindow, cjk_ambiguous_widths);
   gtk_widget_class_bind_template_child (widget_class, PtyxisPreferencesWindow, cursor_blink_mode);
@@ -1012,6 +1028,7 @@ ptyxis_preferences_window_class_init (PtyxisPreferencesWindowClass *klass)
   gtk_widget_class_bind_template_child (widget_class, PtyxisPreferencesWindow, scrollbar_policy);
   gtk_widget_class_bind_template_child (widget_class, PtyxisPreferencesWindow, shortcut_close_other_tabs);
   gtk_widget_class_bind_template_child (widget_class, PtyxisPreferencesWindow, shortcut_close_tab);
+  gtk_widget_class_bind_template_child (widget_class, PtyxisPreferencesWindow, shortcut_close_window);
   gtk_widget_class_bind_template_child (widget_class, PtyxisPreferencesWindow, shortcut_copy_clipboard);
   gtk_widget_class_bind_template_child (widget_class, PtyxisPreferencesWindow, shortcut_detach_tab);
   gtk_widget_class_bind_template_child (widget_class, PtyxisPreferencesWindow, shortcut_focus_tab_1);
@@ -1032,8 +1049,10 @@ ptyxis_preferences_window_class_init (PtyxisPreferencesWindowClass *klass)
   gtk_widget_class_bind_template_child (widget_class, PtyxisPreferencesWindow, shortcut_new_window);
   gtk_widget_class_bind_template_child (widget_class, PtyxisPreferencesWindow, shortcut_paste_clipboard);
   gtk_widget_class_bind_template_child (widget_class, PtyxisPreferencesWindow, shortcut_popup_menu);
+  gtk_widget_class_bind_template_child (widget_class, PtyxisPreferencesWindow, shortcut_set_title);
   gtk_widget_class_bind_template_child (widget_class, PtyxisPreferencesWindow, shortcut_preferences);
   gtk_widget_class_bind_template_child (widget_class, PtyxisPreferencesWindow, shortcut_primary_menu);
+  gtk_widget_class_bind_template_child (widget_class, PtyxisPreferencesWindow, shortcut_tab_menu);
   gtk_widget_class_bind_template_child (widget_class, PtyxisPreferencesWindow, shortcut_reset);
   gtk_widget_class_bind_template_child (widget_class, PtyxisPreferencesWindow, shortcut_reset_and_clear);
   gtk_widget_class_bind_template_child (widget_class, PtyxisPreferencesWindow, shortcut_search);
@@ -1055,6 +1074,7 @@ ptyxis_preferences_window_class_init (PtyxisPreferencesWindowClass *klass)
 
   gtk_widget_class_bind_template_callback (widget_class, ptyxis_preferences_window_profile_row_activated_cb);
   gtk_widget_class_bind_template_callback (widget_class, ptyxis_preferences_window_show_all_cb);
+  gtk_widget_class_bind_template_callback (widget_class, ptyxis_preferences_window_spin_row_show_decimal_cb);
 
   gtk_widget_class_install_action (widget_class,
                                    "profile.add",
