@@ -782,6 +782,18 @@ ptyxis_window_active_tab_bell_cb (PtyxisWindow *self,
   ptyxis_window_visual_bell (self);
 }
 
+static void
+ptyxis_window_active_tab_commit_cb (PtyxisWindow *self,
+                                    const char   *str,
+                                    PtyxisTab    *tab)
+{
+  g_assert (PTYXIS_IS_WINDOW (self));
+  g_assert (PTYXIS_IS_TAB (tab));
+
+  if (self->is_fullscreen)
+    ptyxis_fullscreen_box_unreveal (self->fullscreen_box);
+}
+
 static void
 ptyxis_window_close_action (GtkWidget  *widget,
                             const char *action_name,
@@ -1467,6 +1479,30 @@ ptyxis_window_update_menu_visibility (PtyxisWindow *self)
   gtk_widget_set_visible (GTK_WIDGET (self->new_terminal_menu_button), visible);
 }
 
+static void
+notify_decoration_layout_cb (PtyxisWindow *self,
+                             GParamSpec   *pspec,
+                             GtkSettings  *gtk_settings)
+{
+  g_autofree char *layout = NULL;
+  gboolean inverted = FALSE;
+  const char *colon;
+  const char *close_;
+
+  g_assert (PTYXIS_IS_WINDOW (self));
+  g_assert (GTK_IS_SETTINGS (gtk_settings));
+
+  g_object_get (gtk_settings,
+                "gtk-decoration-layout", &layout,
+                NULL);
+
+  if ((colon = strchr (layout, ':')) && (close_ = strstr (layout, "close")))
+    inverted = close_ < colon;
+
+  if (self->tab_bar)
+    adw_tab_bar_set_inverted (self->tab_bar, inverted);
+}
+
 static void
 ptyxis_window_constructed (GObject *object)
 {
@@ -1477,6 +1513,7 @@ ptyxis_window_constructed (GObject *object)
   g_autoptr(GMenuModel) profile_menu = NULL;
   g_autoptr(GMenuModel) container_menu = NULL;
   g_autoptr(GMenu) menu = NULL;
+  GtkSettings *gtk_settings;
 
   G_OBJECT_CLASS (ptyxis_window_parent_class)->constructed (object);
 
@@ -1516,6 +1553,14 @@ ptyxis_window_constructed (GObject *object)
                            self,
                            G_CONNECT_SWAPPED);
   ptyxis_window_update_menu_visibility (self);
+
+  gtk_settings = gtk_settings_get_default ();
+  g_signal_connect_object (gtk_settings,
+                           "notify::gtk-decoration-layout",
+                           G_CALLBACK (notify_decoration_layout_cb),
+                           self,
+                           G_CONNECT_SWAPPED);
+  notify_decoration_layout_cb (self, NULL, gtk_settings);
 }
 
 static void
@@ -1791,6 +1836,11 @@ ptyxis_window_init (PtyxisWindow *self)
                                  G_CALLBACK (ptyxis_window_active_tab_bell_cb),
                                  self,
                                  G_CONNECT_SWAPPED);
+  g_signal_group_connect_object (self->active_tab_signals,
+                                 "commit",
+                                 G_CALLBACK (ptyxis_window_active_tab_commit_cb),
+                                 self,
+                                 G_CONNECT_SWAPPED);
   g_signal_group_connect_object (self->active_tab_signals,
                                  "notify::process-leader-kind",
                                  G_CALLBACK (ptyxis_window_notify_process_leader_kind_cb),
